@@ -174,7 +174,7 @@ func DecodeBaseBlocks(ctx *ParsingContext, l log.Logger, file *hclparse.File, in
 		errs = errs.Append(err)
 	}
 
-	localsAsCtyVal, err := convertValuesMapToCtyVal(locals)
+	localsAsCtyVal, err := ConvertValuesMapToCtyVal(locals)
 	if err != nil {
 		return nil, err
 	}
@@ -216,7 +216,7 @@ func flagsAsCty(ctx *ParsingContext, tgFlags FeatureFlags) (cty.Value, error) {
 		}
 	}
 
-	flagsAsCtyVal, err := convertValuesMapToCtyVal(evaluatedFlags)
+	flagsAsCtyVal, err := ConvertValuesMapToCtyVal(evaluatedFlags)
 	if err != nil {
 		return cty.NilVal, err
 	}
@@ -358,6 +358,14 @@ func PartialParseConfigString(ctx *ParsingContext, l log.Logger, configPath, con
 func PartialParseConfig(ctx *ParsingContext, l log.Logger, file *hclparse.File, includeFromChild *IncludeConfig) (*TerragruntConfig, error) {
 	errs := &errors.MultiError{}
 
+	// Detect and block deprecated configurations early, before attempting to parse.
+	// This ensures included configs with deprecated syntax get clear error messages
+	// instead of cryptic "Could not find Terragrunt configuration settings" errors.
+	// See: https://github.com/gruntwork-io/terragrunt/issues/4983
+	if err := DetectDeprecatedConfigurations(ctx, l, file); err != nil {
+		return nil, err
+	}
+
 	ctx = ctx.WithTrackInclude(nil)
 
 	// read unit files and add to context
@@ -451,7 +459,7 @@ func PartialParseConfig(ctx *ParsingContext, l log.Logger, file *hclparse.File,
 			output.TerragruntDependencies = decoded.Dependencies
 			// Convert dependency blocks into module dependency lists. If we already decoded some dependencies,
 			// merge them in. Otherwise, set as the new list.
-			dependencies := dependencyBlocksToModuleDependencies(decoded.Dependencies)
+			dependencies := dependencyBlocksToModuleDependencies(l, decoded.Dependencies)
 			if output.Dependencies != nil {
 				output.Dependencies.Merge(dependencies)
 			} else {
